@@ -2,22 +2,22 @@ import dask.array as da
 import matplotlib
 import numpy as np
 import pandas as pd
+import pytest
 import scanpy as sc
 import spatialdata_plot  # noqa: F401
 from anndata import AnnData
 from spatial_image import to_spatial_image
-from spatialdata import SpatialData
-from spatialdata._core.query.relational_query import _get_unique_label_values_as_index
+from spatialdata import SpatialData, get_element_instances
 from spatialdata.models import TableModel
 
-from tests.conftest import PlotTester, PlotTesterMeta
+from tests.conftest import DPI, PlotTester, PlotTesterMeta
 
+RNG = np.random.default_rng(seed=42)
 sc.pl.set_rcParams_defaults()
-sc.set_figure_params(dpi=40, color_map="viridis")
+sc.set_figure_params(dpi=DPI, color_map="viridis")
 matplotlib.use("agg")  # same as GitHub action runner
 _ = spatialdata_plot
 
-RNG = np.random.default_rng(seed=42)
 # WARNING:
 # 1. all classes must both subclass PlotTester and use metaclass=PlotTesterMeta
 # 2. tests which produce a plot must be prefixed with `test_plot_`
@@ -28,7 +28,7 @@ RNG = np.random.default_rng(seed=42)
 
 class TestLabels(PlotTester, metaclass=PlotTesterMeta):
     def test_plot_can_render_labels(self, sdata_blobs: SpatialData):
-        sdata_blobs.pl.render_labels(elements="blobs_labels").pl.show()
+        sdata_blobs.pl.render_labels(element="blobs_labels").pl.show()
 
     def test_plot_can_render_multiscale_labels(self, sdata_blobs: SpatialData):
         sdata_blobs["table"].obs["region"] = "blobs_multiscale_labels"
@@ -69,10 +69,10 @@ class TestLabels(PlotTester, metaclass=PlotTesterMeta):
     def test_plot_can_stack_render_labels(self, sdata_blobs: SpatialData):
         (
             sdata_blobs.pl.render_labels(
-                elements="blobs_labels", na_color="red", fill_alpha=1, outline_alpha=0, outline=False
+                element="blobs_labels", na_color="red", fill_alpha=1, outline_alpha=0, outline=False
             )
             .pl.render_labels(
-                elements="blobs_labels", na_color="blue", fill_alpha=0, outline_alpha=1, outline=True, contour_px=10
+                element="blobs_labels", na_color="blue", fill_alpha=0, outline_alpha=1, outline=True, contour_px=15
             )
             .pl.show()
         )
@@ -86,8 +86,8 @@ class TestLabels(PlotTester, metaclass=PlotTesterMeta):
         table.uns["spatialdata_attrs"]["region"] = "blobs_multiscale_labels"
         table = table[:, ~table.var_names.isin(["channel_0_sum"])]
         sdata_blobs["multi_table"] = table
-        sdata_blobs.pl.render_labels(
-            color=["channel_0_sum", "channel_1_sum"], table_name=["table", "multi_table"]
+        sdata_blobs.pl.render_labels("blobs_labels", color="channel_0_sum", table_name="table").pl.render_labels(
+            "blobs_multiscale_labels", color="channel_1_sum", table_name="multi_table"
         ).pl.show()
 
     def test_can_plot_with_one_element_color_table(self, sdata_blobs: SpatialData):
@@ -96,56 +96,37 @@ class TestLabels(PlotTester, metaclass=PlotTesterMeta):
         table.uns["spatialdata_attrs"]["region"] = "blobs_multiscale_labels"
         table = table[:, ~table.var_names.isin(["channel_0_sum"])]
         sdata_blobs["multi_table"] = table
-        sdata_blobs.pl.render_labels(
-            color=["channel_0_sum", "channel_1_sum"], table_name=["table", "multi_table"]
+        sdata_blobs.pl.render_labels("blobs_labels", color="channel_0_sum", table_name="table").pl.render_labels(
+            "blobs_multiscale_labels", color="channel_1_sum", table_name="multi_table"
         ).pl.show()
 
-    def test_plot_label_categorical_color(self, sdata_blobs: SpatialData):
-        n_obs = max(_get_unique_label_values_as_index(sdata_blobs["blobs_labels"]))
+    @pytest.mark.parametrize(
+        "label",
+        [
+            "blobs_labels",
+            "blobs_multiscale_labels",
+        ],
+    )
+    def test_plot_label_categorical_color(self, sdata_blobs: SpatialData, label: str):
+        self._make_tablemodel_with_categorical_labels(sdata_blobs, label)
+
+    def _make_tablemodel_with_categorical_labels(self, sdata_blobs, label):
+        n_obs = max(get_element_instances(sdata_blobs[label]))
         adata = AnnData(
-            RNG.normal(size=(n_obs, 10)), obs=pd.DataFrame(RNG.normal(size=(n_obs, 3)), columns=["a", "b", "c"])
+            RNG.normal(size=(n_obs, 10)),
+            obs=pd.DataFrame(RNG.normal(size=(n_obs, 3)), columns=["a", "b", "c"]),
         )
         adata.obs["instance_id"] = np.arange(adata.n_obs)
         adata.obs["category"] = RNG.choice(["a", "b", "c"], size=adata.n_obs)
+        adata.obs["category"][:3] = ["a", "b", "c"]
         adata.obs["instance_id"] = list(range(adata.n_obs))
-        adata.obs["region"] = "blobs_labels"
-        table = TableModel.parse(adata=adata, region_key="region", instance_key="instance_id", region="blobs_labels")
-        sdata_blobs["other_table"] = table
-
-        # with pytest.raises(ValueError, match="could not convert string"):
-        #     sdata_blobs.pl.render_labels('blobs_labels', color='category').pl.show()
-        sdata_blobs["other_table"].obs["category"] = sdata_blobs["other_table"].obs["category"].astype("category")
-        sdata_blobs.pl.render_labels("blobs_labels", color="category").pl.show()
-
-    def test_plot_multiscale_label_categorical_color(self, sdata_blobs: SpatialData):
-        n_obs = max(_get_unique_label_values_as_index(sdata_blobs["blobs_multiscale_labels"]))
-        adata = AnnData(
-            RNG.normal(size=(n_obs, 10)), obs=pd.DataFrame(RNG.normal(size=(n_obs, 3)), columns=["a", "b", "c"])
-        )
-        adata.obs["instance_id"] = np.arange(adata.n_obs)
-        adata.obs["category"] = RNG.choice(["a", "b", "c"], size=adata.n_obs)
-        adata.obs["instance_id"] = list(range(adata.n_obs))
-        adata.obs["region"] = "blobs_multiscale_labels"
+        adata.obs["region"] = label
         table = TableModel.parse(
-            adata=adata, region_key="region", instance_key="instance_id", region="blobs_multiscale_labels"
+            adata=adata,
+            region_key="region",
+            instance_key="instance_id",
+            region=label,
         )
         sdata_blobs["other_table"] = table
-
         sdata_blobs["other_table"].obs["category"] = sdata_blobs["other_table"].obs["category"].astype("category")
-        sdata_blobs.pl.render_labels("blobs_multiscale_labels", color="category").pl.show()
-
-    # def test_plot_multiscale_label_coercable_categorical_color(self, sdata_blobs: SpatialData):
-    #     n_obs = max(_get_unique_label_values_as_index(sdata_blobs["blobs_multiscale_labels"]))
-    #     adata = AnnData(
-    #         RNG.normal(size=(n_obs, 10)), obs=pd.DataFrame(RNG.normal(size=(n_obs, 3)), columns=["a", "b", "c"])
-    #     )
-    #     adata.obs["instance_id"] = np.arange(adata.n_obs)
-    #     adata.obs["category"] = RNG.choice(["a", "b", "c"], size=adata.n_obs)
-    #     adata.obs["instance_id"] = list(range(adata.n_obs))
-    #     adata.obs["region"] = "blobs_multiscale_labels"
-    #     table = TableModel.parse(
-    #         adata=adata, region_key="region", instance_key="instance_id", region="blobs_multiscale_labels"
-    #     )
-    #     sdata_blobs["other_table"] = table
-    #
-    #     sdata_blobs.pl.render_labels("blobs_multiscale_labels", color="category").pl.show()
+        sdata_blobs.pl.render_labels(label, color="category").pl.show()
